<?php

require_once get_template_directory() . '/includes/loader.php';

add_action( 'after_setup_theme', 'arkina_setup_theme' );
add_action( 'after_setup_theme', 'arkina_load_default_hooks' );


function arkina_setup_theme() {

	load_theme_textdomain( 'arkina', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-lightbox' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'editor-styles' );
	add_theme_support( 'post', 'page-attributes' );
    
	// Set the default content width.
	$GLOBALS['content_width'] = 525;
	
	/*---------- Register image sizes ----------*/
	
	//Register image sizes
	add_image_size( 'arkina_947x532', 947, 532, true ); //arkina_947x532 Masonary Project
	add_image_size( 'arkina_473x533', 473, 533, true ); //arkina_473x533 Masonary Project
	add_image_size( 'arkina_353x529', 353, 529, true ); //arkina_353x529 Masonary Project	
	add_image_size( 'arkina_353x494', 353, 494, true ); //arkina_353x494 Masonary Project
	add_image_size( 'arkina_353x378', 353, 378, true ); //arkina_353x378 Masonary Project
	add_image_size( 'arkina_353x334', 353, 334, true ); //arkina_353x334 Masonary Project
	add_image_size( 'arkina_353x235', 353, 235, true ); //arkina_353x235 Masonary Project
	add_image_size( 'arkina_466x524', 466, 524, true ); //arkina_466x524 Masonary Project
	add_image_size( 'arkina_932x523', 932, 523, true ); //arkina_932x523 Masonary Project
	add_image_size( 'arkina_932x1045', 932, 1045, true ); //arkina_932x1045 Masonary Project	
	add_image_size( 'arkina_467x548', 467, 548, true ); //arkina_467x548 Project Grid
	add_image_size( 'arkina_220x220', 220, 220, true ); //arkina_220x220 Blog Posts
	add_image_size( 'arkina_480x320', 480, 320, true ); //arkina_480x320 Blog Posts
	add_image_size( 'arkina_80x80', 80, 80, true ); //arkina_80x80 Testimonial Carousel
	add_image_size( 'arkina_435x400', 435, 400, true ); //arkina_435x400 Team Carousel
	add_image_size( 'arkina_200x200', 200, 200, true ); //arkina_200x200 Service Carousel
	add_image_size( 'arkina_1170x500', 1170, 500, true ); //arkina_1170x500 Blog Classic
	
	/*---------- Register image sizes ends ----------*/
	
	
	
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'arkina' ),
		'sidebar_menu' => esc_html__( 'Sidebar Menu', 'arkina' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'      => 250,
		'height'     => 250,
		'flex-width' => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style();
	add_action( 'admin_init', 'arkina_admin_init', 2000000 );
}

/**
 * [arkina_admin_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */



function arkina_admin_init() {
	remove_action( 'admin_notices', array( 'ReduxFramework', '_admin_notices' ), 99 );
}

/*---------- Sidebar settings ----------*/

/**
 * [arkina_widgets_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
function arkina_widgets_init() {

	global $wp_registered_sidebars;

	$theme_options = get_theme_mod( 'arkina' . '_options-mods' );

	register_sidebar( array(
		'name'          => esc_html__( 'Default Sidebar', 'arkina' ),
		'id'            => 'default-sidebar',
		'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'arkina' ),
		'before_widget' => '<div id="%1$s" class="widget sidebar-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="sidebar-title"><h5>',
		'after_title'   => '</h5></div>',
	) );
	register_sidebar(array(
		'name' => esc_html__('Footer Widget', 'arkina'),
		'id' => 'footer-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'arkina'),
		'before_widget'=>'<div class="col-lg-6 col-md-6 col-sm-12 footer-column"><div id="%1$s" class="footer-widget %2$s">',
		'after_widget'=>'</div></div>',
		'before_title' => '<h5>',
		'after_title' => '</h5>'
	));
	if ( class_exists( '\Elementor\Plugin' )){	
	register_sidebar(array(
	  'name' => esc_html__( 'Blog Listing', 'arkina' ),
	  'id' => 'blog-sidebar',
	  'description' => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'arkina' ),
	  'before_widget'=>'<div id="%1$s" class="widget sidebar-widget %2$s">',
	  'after_widget'=>'</div>',
	  'before_title' => '<div class="sidebar-title"><h5>',
	  'after_title' => '</h5></div>'
	));
	}
	if ( ! is_object( arkina_WSH() ) ) {
		return;
	}

	$sidebars = arkina_set( $theme_options, 'custom_sidebar_name' );

	foreach ( array_filter( (array) $sidebars ) as $sidebar ) {

		if ( arkina_set( $sidebar, 'topcopy' ) ) {
			continue;
		}

		$name = $sidebar;
		if ( ! $name ) {
			continue;
		}
		$slug = str_replace( ' ', '_', $name );

		register_sidebar( array(
			'name'          => $name,
			'id'            => sanitize_title( $slug ),
			'before_widget' => '<div id="%1$s" class="%2$s widget sidebar-widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="sidebar-title"><h5>',
			'after_title'   => '</h5></div>',
		) );
	}

	update_option( 'wp_registered_sidebars', $wp_registered_sidebars );
}

add_action( 'widgets_init', 'arkina_widgets_init' );

/*---------- Sidebar settings ends ----------*/

/*---------- Gutenberg settings ----------*/

function arkina_gutenberg_editor_palette_styles() {
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'strong yellow', 'arkina' ),
            'slug' => 'strong-yellow',
            'color' => '#f7bd00',
        ),
        array(
            'name' => esc_html__( 'strong white', 'arkina' ),
            'slug' => 'strong-white',
            'color' => '#fff',
        ),
		array(
            'name' => esc_html__( 'light black', 'arkina' ),
            'slug' => 'light-black',
            'color' => '#242424',
        ),
        array(
            'name' => esc_html__( 'very light gray', 'arkina' ),
            'slug' => 'very-light-gray',
            'color' => '#797979',
        ),
        array(
            'name' => esc_html__( 'very dark black', 'arkina' ),
            'slug' => 'very-dark-black',
            'color' => '#000000',
        ),
    ) );
	
	add_theme_support( 'editor-font-sizes', array(
		array(
			'name' => esc_html__( 'Small', 'arkina' ),
			'size' => 10,
			'slug' => 'small'
		),
		array(
			'name' => esc_html__( 'Normal', 'arkina' ),
			'size' => 15,
			'slug' => 'normal'
		),
		array(
			'name' => esc_html__( 'Large', 'arkina' ),
			'size' => 24,
			'slug' => 'large'
		),
		array(
			'name' => esc_html__( 'Huge', 'arkina' ),
			'size' => 36,
			'slug' => 'huge'
		)
	) );
	
}
add_action( 'after_setup_theme', 'arkina_gutenberg_editor_palette_styles' );

/*---------- Gutenberg settings ends ----------*/

/*---------- Enqueue Styles and Scripts ----------*/

function arkina_enqueue_scripts() {
	$options = arkina_WSH()->option();
	$header_meta = get_post_meta( get_the_ID(), 'header_style_settings');
	$header_option = $options->get( 'header_style_settings' );
	$header = ( $header_meta ) ? $header_meta['0'] : $header_option;
	
	if( $options->get( 'main_color_scheme' ) ){
		$maincolor = str_replace( '#', '' , $options->get( 'main_color_scheme' ));
		
	}else{
		$maincolor = str_replace( '#', '' , '#F68A0A' );
	}
	if( $options->get( 'secondary_color_scheme' ) ){
		$secondcolor = str_replace( '#', '' , $options->get( 'secondary_color_scheme' ));
	}
	else{
		$secondcolor = str_replace( '#', '' , '#171818' );	
	}
	
    //styles
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css' );	
	wp_enqueue_style( 'arkina-font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css' );
	wp_enqueue_style( 'simple-line-icons', get_template_directory_uri() . '/assets/css/simple-line-icons.css' );
	wp_enqueue_style( 'flaticon', get_template_directory_uri() . '/assets/css/flaticon.css' );
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css' );
	wp_enqueue_style( 'owl', get_template_directory_uri() . '/assets/css/owl.css' );
	wp_enqueue_style( 'arkina-swiper', get_template_directory_uri() . '/assets/css/swiper.css' );
	wp_enqueue_style( 'jquery-ui', get_template_directory_uri() . '/assets/css/jquery-ui.css' );
	wp_enqueue_style( 'jquery-fancybox', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css' );
	if( $header == 'header_v8'){
	wp_enqueue_style( 'crossroad', get_template_directory_uri() . '/assets/css/crossroad.css' );
	}
	wp_enqueue_style( 'arkina-main', get_stylesheet_uri() );
	wp_enqueue_style( 'arkina-main-style', get_template_directory_uri() . '/assets/css/style.css' );
	wp_enqueue_style( 'arkina-custom', get_template_directory_uri() . '/assets/css/custom.css' );
	wp_enqueue_style( 'arkina-tut', get_template_directory_uri() . '/assets/css/tut.css' );
	wp_enqueue_style( 'arkina-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );
	
	
    //scripts
	wp_enqueue_script( 'jquery-ui-core');
	wp_enqueue_script( 'popper', get_template_directory_uri().'/assets/js/popper.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri().'/assets/js/bootstrap.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-ui', get_template_directory_uri().'/assets/js/jquery-ui.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-fancybox', get_template_directory_uri().'/assets/js/jquery.fancybox.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'imagesloaded', get_template_directory_uri().'/assets/js/imagesloaded.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'charming', get_template_directory_uri().'/assets/js/charming.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'tweenmax', get_template_directory_uri().'/assets/js/TweenMax.js', array( 'jquery' ), '2.1.2', true );			
	wp_enqueue_script( 'main', get_template_directory_uri().'/assets/js/main.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'arkina-swiper', get_template_directory_uri().'/assets/js/swiper.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'mixitup', get_template_directory_uri().'/assets/js/mixitup.js', array( 'jquery' ), '2.1.2', true );
	if( $header == 'header_v8'){
	wp_enqueue_script( 'crossroad', get_template_directory_uri().'/assets/js/crossroad.js', array( 'jquery' ), '2.1.2', true );
	}
	wp_enqueue_script( 'isotope', get_template_directory_uri().'/assets/js/isotope.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'bxslider', get_template_directory_uri().'/assets/js/bxslider.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'owl', get_template_directory_uri().'/assets/js/owl.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'appear', get_template_directory_uri().'/assets/js/appear.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'wow', get_template_directory_uri().'/assets/js/wow.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'arkina-main-custom-script', get_template_directory_uri().'/assets/js/custom-script.js', array(), false, true );
	if( is_singular() ) wp_enqueue_script('comment-reply');
}
add_action( 'wp_enqueue_scripts', 'arkina_enqueue_scripts' );

/*---------- Enqueue styles and scripts ends ----------*/

/*---------- Google fonts ----------*/

function arkina_fonts_url() {
	
	$fonts_url = ''; 
		
		$font_families['Manrope'] = 'Manrope:300,400,500,600,700';		
		
		$font_families = apply_filters( 'ARKINA/includes/classes/header_enqueue/font_families', $font_families );

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$protocol  = is_ssl() ? 'https' : 'http';
		$fonts_url = add_query_arg( $query_args, $protocol . '://fonts.googleapis.com/css' );

		return esc_url_raw($fonts_url);

}

function arkina_theme_styles() {
    wp_enqueue_style( 'arkina-theme-fonts', arkina_fonts_url(), array(), null );
}

add_action( 'wp_enqueue_scripts', 'arkina_theme_styles' );
add_action( 'admin_enqueue_scripts', 'arkina_theme_styles' );

/*---------- Google fonts ends ----------*/

/*---------- More functions ----------*/

// 1) arkina_set function

/**
 * [arkina_set description]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
if ( ! function_exists( 'arkina_set' ) ) {
	function arkina_set( $var, $key, $def = '' ) {

		if ( is_object( $var ) && isset( $var->$key ) ) {
			return $var->$key;
		} elseif ( is_array( $var ) && isset( $var[ $key ] ) ) {
			return $var[ $key ];
		} elseif ( $def ) {
			return $def;
		} else {
			return false;
		}
	}
}

// 2) arkina_add_editor_styles function

function arkina_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'arkina_add_editor_styles' );

// 3) Add specific CSS class by filter body class.

$options = arkina_WSH()->option(); 
if( arkina_set($options, 'boxed_wrapper') ){

add_filter( 'body_class', function( $classes ) {
    $classes[] = 'boxed_wrapper';
    return $classes;
} );
}




function arkina_related_products_limit() {
  global $product;
	
	$args['posts_per_page'] = 6;
	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'arkina_related_products_args', 20 );
  function arkina_related_products_args( $args ) {
	$args['posts_per_page'] = 3; // 4 related products
	$args['columns'] = 1; // arranged in 2 columns
	return $args;
}

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327836&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        