<?php namespace ARCHWAYPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Banner extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'archway_banner';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Archway Banner', 'archway' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-banner';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'archway' ];
    }
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'banner',
            [
                'label' => esc_html__( 'Banner', 'archway' ),
            ]
        );
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'archway'),
					'2' => esc_html__( 'Style Two ', 'archway'),
					'3' => esc_html__( 'Style Three ', 'archway'),
					'4' => esc_html__( 'Style Four ', 'archway'),
					'5' => esc_html__( 'Style Five ', 'archway'),
				),
			]
		);
		$this->add_control(
			'image',
			[
				'label' => __( 'Banner Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,			
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'image2',
			[
				'label' => __( 'Banner Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,	
				'condition' => ['layout_control' => ['2', '3', '4', '5'], ],			
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'image3',
			[
				'label' => __( 'Banner Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,	
				'condition' => ['layout_control' => ['2', '3', '4', '5'], ],			
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'image4',
			[
				'label' => __( 'Banner Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,	
				'condition' => ['layout_control' => ['2', '3', '4', '5'], ],			
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label'       => __( 'Small Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => ['layout_control' => ['3', '4'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Small Title', 'archway' ),
			]
		);		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'condition' => ['layout_control' => [ '2', '3', '4', '5'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'archway' ),
			]
		);		
		$this->add_control(
			'btn_link',
			[
				  'label' => __( 'Button Url', 'archway' ),
				  'type' => Controls_Manager::URL,
				  'condition' => ['layout_control' => ['3', '4'], ],
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'layout_control' => '4', ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'archway' ),
			]
		);
		$this->add_control(
			'sub_title2',
			[
				'label'       => __( 'Small Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => ['layout_control' => ['3'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Small Title', 'archway' ),
			]
		);
		$this->add_control(
			'title2',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'condition' => [ 'layout_control' => ['3', '4'], ],
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$this->add_control(
			'btn_link2',
			[
				  'label' => __( 'Button Url', 'archway' ),
				  'type' => Controls_Manager::URL,
				  'condition' => [ 'layout_control' => ['3', '4'], ],
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		$this->add_control(
			'title3',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'condition' => [ 'layout_control' => ['3'], ],
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$this->add_control(
			'phone_title',
			[
				'label'       => __( 'Phone Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'layout_control' => '4', ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Phone Title', 'archway' ),
			]
		);	
		$this->add_control(
			'phone_no',
			[
				'label'       => __( 'Phone Number', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'layout_control' => '4', ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Phone Number', 'archway' ),
			]
		);
		$this->add_control(
			'email_address',
			[
				'label'       => __( 'Email Address', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'layout_control' => '4', ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Email Address', 'archway' ),
			]
		);
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'icons',
			[
				'label' => esc_html__('Enter The icons', 'archway'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
			]
			
		);
		$repeater->add_control(
			'social_link',
			[
				'label' => __( 'Social Url', 'archway' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$this->add_control(
			'social',
			[
				'label'                 => __('Add Social Media', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '4', ],
			]
		);
		
		$this->add_control(
			'post_title',
			[
				'label'       => __( 'Posts Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'condition' => [ 'layout_control' => '4', ],
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Posts Title', 'archway' ),
			]
		);
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'post_img',
			[
				'label' => esc_html__('Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_sub_title',
			[
				'label'       => __( 'Sub Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_title',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'post_link',
			[
				'label' => __( 'External Url', 'archway' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$this->add_control(
			'posts',
			[
				'label'                 => __('Add Post Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '4', ],
			]
		);
		
		
		$this->end_controls_section();
		
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{	
		
		/**Layout Control Style**/		
		$this->start_controls_section(
			'archway_layout_style',
			[
				'label' => esc_html__('Archway Layout Setting', 'archway'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
            'archway_layout_margin',
            [
                'label'              => __( 'Spacing', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-banner-section' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_responsive_control(
            'archway_layout_padding',
            [
                'label'              => __( 'Gapping', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-banner-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_control(
			'archway_layout_background',
			[
				'label'                 => __( 'Background', 'archway' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'archway_layout_bgtype',
				'label' => __( 'Button Background', 'archway' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .archway-banner-section',				
			]
		);
		$this->end_controls_section();				
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
    ?>
    
    <?php if($settings['layout_control'] == '5') :?>
    
    <!-- Banner Section -->
    <section class="banner-two alternate archway-banner-section">        
        <div class="banner-container">
            <!--Slide Item-->
            <div class="slide-item">
                <div class="auto-container">
                    <div class="content-box">
                        <div class="content">
                            <?php if($settings['image']['id']){ ?><div class="vector-1"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"></div><?php } ?>
                            <?php if($settings['image2']['id']){ ?><div class="thumb-1"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"></div><?php } ?>
                            <?php if($settings['image3']['id']){ ?><div class="thumb-2"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image3']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"></div><?php } ?>
                            <?php if($settings['image4']['id']){ ?><div class="thumb-3"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image4']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"></div><?php } ?>
                            <?php if($settings['title'] || $settings['text']){ ?>
                            <div class="clearfix">
                                <div class="inner">
                                    <?php if($settings['title']){ ?><h1><span class="big-one"><?php echo wp_kses($settings['title'], true);?></span></h1><?php } ?>
                                    <?php if($settings['text']){ ?><div class="text"><?php echo wp_kses($settings['text'], true);?></div><?php } ?>
                                </div>                                
                            </div>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!--End Banner Section -->
    
	<?php elseif($settings['layout_control'] == '4') :?>
	
    <!-- Banner One -->
    <section class="banner-one archway-banner-section">
        <div class="banner-one_color-height"></div>
        <div class="auto-container">
            <?php if($settings['image']['id'] || $settings['title'] || $settings['text']){ ?>
            <div class="upper-box">
                <div class="row clearfix">
                    <?php if($settings['image']['id']){ ?>
                    <!-- Image Column -->
                    <div class="image-column col-lg-6 col-md-12 col-sm-12">
                        <div class="image">
                            <img src="<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" />
                        </div>
                    </div>
                    <?php } ?>     
                    <?php if($settings['title'] || $settings['text']){ ?>               
                    <!-- Content Column -->
                    <div class="content-column col-lg-6 col-md-12 col-sm-12">
                        <div class="content">
                            <?php if($settings['title']){ ?><h1><?php echo wp_kses($settings['title'], true);?></h1><?php } ?>
                            <?php if($settings['text']){ ?><div class="text"><?php echo wp_kses($settings['text'], true);?></div><?php } ?>
                        </div>
                    </div>
                    <?php } ?>
                </div>
            </div>
            <?php } ?> 
            <div class="lower-box">
                <div class="row clearfix">
                    <!-- Column -->
                    <div class="info-column col-xxl-3 col-xl-3 col-lg-6 col-md-12 col-sm-12">
                        <div class="inner-column">
                            <?php if($settings['phone_title']){ ?><h2><?php echo wp_kses($settings['phone_title'], true);?></h2><?php } ?>
                            <?php if($settings['phone_no'] || $settings['email_address']){ ?>
                            <ul class="list">
                                <?php if($settings['phone_no']){ ?><li><?php echo wp_kses($settings['phone_no'], true);?></li><?php } ?>
                                <?php if($settings['email_address']){ ?><li><?php echo wp_kses($settings['email_address'], true);?></li><?php } ?>
                            </ul>
                            <?php } ?>
                            <div class="social-links">
                                <ul class="clearfix">
                                    <?php 
										foreach($settings['social'] as $key => $item):
										$icons = $item[ 'icons' ];
									?>
                                    <li><a href="<?php echo esc_url($item['social_link']['url']);?>"><i class="icon"><?php \Elementor\Icons_Manager::render_icon( $icons ); ?></i></a></li>
                                    <?php endforeach;?>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <?php if($settings['image2']['id'] || $settings['btn_link']['url']){ ?>
                    <!-- Column -->
                    <div class="video-column col-xxl-3 col-xl-3 col-lg-6 col-md-12 col-sm-12">
                        <!-- Video Box -->
						<div class="video-box">
							<figure class="video-image">
								<?php if($settings['image2']['id']){ ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['image2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"><?php } ?> 
								<?php if($settings['btn_link']['url']){ ?><a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="lightbox-image overlay-box"><span class="fa-solid fa-play fa-fw"><i class="ripple"></i></span></a><?php } ?>
							</figure>
						</div>
                    </div>
                    <?php } ?>
                    <?php if($settings['image3']['id'] || $settings['btn_link2']['url'] || $settings['title2']){ ?>
                    <!-- Column -->
                    <div class="projects-column col-xxl-3 col-xl-3 col-lg-6 col-md-12 col-sm-12">
                        <?php if($settings['image3']['id'] || $settings['btn_link2']['url']){ ?>
                        <div class="image">
                            <?php if($settings['image3']['id']){ ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['image3']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" /><?php } ?> 
                            <?php if($settings['btn_link2']['url']){ ?><a class="all_project" href="<?php echo esc_url($settings['btn_link2']['url']); ?>"><?php echo wp_kses($settings['btn_title'], true);?> <span class="fa-solid fa-arrow-right fa-fw"></span></a><?php } ?> 
                        </div>
                        <?php } ?>
                        <?php if($settings['title2']){ ?>
                        <div class="content">
                            <h2><a href="<?php echo esc_url($settings['btn_link2']['url']); ?>"><?php echo wp_kses($settings['title2'], true);?></a></h2>
                        </div>
                        <?php } ?>
                    </div>
                    <?php } ?>
                    <!-- Column -->
                    <div class="news-column col-xxl-3 col-xl-3 col-lg-6 col-md-12 col-sm-12">
                        <div class="content">
                            <?php if($settings['post_title']){ ?><h2><?php echo wp_kses($settings['post_title'], true);?></h2><?php } ?>
                            <div class="posts-outer">
                                <?php foreach($settings['posts'] as $key => $item):?>
                                <div class="post-box">
                                    <div class="inner-box">
                                        <?php if($item['post_img']['id']){ ?>
                                        <div class="image">
                                            <img src="<?php echo esc_url(wp_get_attachment_url($item['post_img']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" />
                                        </div>
                                        <?php } ?>
                                        <div class="title"><?php echo wp_kses($item['block_sub_title'], true) ;?></div>
                                        <h5><a href="<?php echo esc_url($item['post_link']['url']);?>"><?php echo wp_kses($item['block_title'], true) ;?></a></h5>
                                    </div>
                                </div>
								<?php endforeach;?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End Banner One -->
    
	<?php elseif($settings['layout_control'] == '3') :?>
    
     <!-- Banner Three -->
    <section class="banner-three archway-banner-section">
        <div class="auto-container">
            <div class="upper-box">
                <div class="row clearfix">
                    <?php if($settings['image']['id']){ ?>
                    <!-- Column -->
                    <div class="column col-lg-3 col-md-6 col-sm-12">
                        <div class="sketch-image">
                            <img src="<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" />
                        </div>
                    </div>
                    <?php } ?>
                    <?php if($settings['sub_title'] || $settings['title'] || $settings['image2']['id']){ ?>
                    <!-- Column -->
                    <div class="column col-lg-6 col-md-12 col-sm-12">
                        <div class="banner-three_content">
                            <?php if($settings['sub_title']){ ?><div class="title"><?php echo wp_kses($settings['sub_title'], true);?></div><?php } ?>
                            <?php if($settings['title']){ ?><h3><a href="<?php echo esc_url($settings['btn_link']['url']); ?>"><?php echo wp_kses($settings['title'], true);?></a></h3><?php } ?>
                            <?php if($settings['image2']['id']){ ?><a class="arrow" href="<?php echo esc_url($settings['btn_link']['url']); ?>"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" /></a><?php } ?>
                        </div>
                    </div>
                    <?php } ?>
                    <?php if($settings['image3']['id']){ ?>
                    <!-- Column -->
                    <div class="column col-lg-3 col-md-6 col-sm-12">
                        <div class="image">
                            <img src="<?php echo esc_url(wp_get_attachment_url($settings['image3']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" />
                        </div>
                    </div>
                    <?php } ?>
                </div>
            </div>
            <div class="lower-box">
                <div class="row clearfix">
                    <?php if($settings['title2']){ ?>
                    <!-- Column -->
                    <div class="column col-lg-6 col-md-12 col-sm-12">
                        <h1><a href="<?php echo esc_url($settings['btn_link2']['url']); ?>"><?php echo wp_kses($settings['title2'], true);?></a></h1>
                    </div>
                    <?php } ?>
                    <?php if($settings['sub_title2'] || $settings['title3'] || $settings['image4']['id']){ ?>
                    <!-- Column -->
                    <div class="column col-lg-6 col-md-12 col-sm-12">
                        <div class="banner-three_content-two">
                            <?php if($settings['sub_title2']){ ?><div class="title"><?php echo wp_kses($settings['sub_title2'], true);?></div><?php } ?>
                            <?php if($settings['title3']){ ?><h3><a href="<?php echo esc_url($settings['btn_link2']['url']); ?>"><?php echo wp_kses($settings['title3'], true);?></a></h3><?php } ?>
                            <?php if($settings['image4']['id']){ ?><a class="arrow" href="<?php echo esc_url($settings['btn_link2']['url']); ?>"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image4']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" /></a><?php } ?>
                        </div>
                    </div>
                    <?php } ?>
                </div>
            </div>
        </div>
    </section>
    <!-- End Banner Three -->
    
    <?php elseif($settings['layout_control'] == '2') :?>
    
    <!-- Banner Section -->
    <section class="banner-two archway-banner-section">        
        <div class="banner-container">
            <!--Slide Item-->
            <div class="slide-item">
                <div class="auto-container">
                    <div class="content-box">
                        <div class="content">
                            <?php if($settings['image']['id']){ ?><div class="vector-1"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"></div><?php } ?>
                            <?php if($settings['image2']['id']){ ?><div class="thumb-1"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"></div><?php } ?>
                            <?php if($settings['image3']['id']){ ?><div class="thumb-2"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image3']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"></div><?php } ?>
                            <?php if($settings['image4']['id']){ ?><div class="thumb-3"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image4']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"></div><?php } ?>
                            <?php if($settings['title'] || $settings['text']){ ?>
                            <div class="clearfix">
                                <div class="inner">
                                    <?php if($settings['title']){ ?><h1><span class="big-one"><?php echo wp_kses($settings['title'], true);?></span></h1><?php } ?>
                                    <?php if($settings['text']){ ?><div class="text"><?php echo wp_kses($settings['text'], true);?></div><?php } ?>
                                </div>                                
                            </div>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!--End Banner Section -->
    
    <?php else: ?>
    
    <!-- Banner Section -->
    <section class="banner-section archway-banner-section">        
        <div class="banner-container">
            <!--Slide Item-->
            <div class="slide-item">
                <div class="bg-layer"></div>
                <div class="auto-container">
                    <?php if($settings['title']){ ?>
                    <div class="content-box">
                        <div class="content">
                            <div class="clearfix">
                                <div class="inner">
                                    <h1><span class="upper-big"><?php echo wp_kses($settings['title'], true);?></span></h1>
                                </div>                                
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                </div>
                <?php if($settings['image']['id']){ ?>
                <div class="lower-image"><img src="<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>"></div>
                <?php } ?>
            </div>
        </div>
    </section>
    <!--End Banner Section -->
    
    <?php endif; ?>   
    <?php
    }
}
