<?php
namespace ARCHWAYPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Banner_Carousel extends Widget_Base {
    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'archway_banner_carousel';
    }
    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Archway Banner Carousel', 'archway' );
    }
    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-banner';
    }
    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'archway' ];
    }
	
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'banner_carousel',
            [
                'label' => esc_html__( 'Banner Carousel', 'archway' ),
            ]
        );
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'archway'),
					'2' => esc_html__( 'Style Two ', 'archway'),
					'3' => esc_html__( 'Style Three ', 'archway'),
					'4' => esc_html__( 'Style Four ', 'archway'),
					'5' => esc_html__( 'Style Five ', 'archway'),
					'6' => esc_html__( 'Style Six ', 'archway'),
					'7' => esc_html__( 'Style Seven ', 'archway'),
				),
			]
		);
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_img',
			[
				'label' => esc_html__('Slide BG Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_sub_title',
			[
				'label'       => __( 'Sub Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_title',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$this->add_control(
			'slides',
			[
				'label'                 => __('Add Slider Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '1', ],
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		

		$repeater->add_control(
			'block_img2',
			[
				'label' => esc_html__('Slide BG Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_img31',
			[
				'label' => esc_html__('Slide Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_img32',
			[
				'label' => esc_html__('Slide Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_img33',
			[
				'label' => esc_html__('Slide Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_img34',
			[
				'label' => esc_html__('Slide Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_sub_title2',
			[
				'label'       => __( 'Sub Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_title2',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_text2',
			[
				'label'       => __( 'Text', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'archway' ),
			]
		);
		$this->add_control(
			'slides_v2',
			[
				'label'                 => __('Add Slider Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '2', ],
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_img3',
			[
				'label' => esc_html__('Slide BG Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_sub_title3',
			[
				'label'       => __( 'Sub Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_title3',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_text3',
			[
				'label'       => __( 'Text', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'archway' ),
			]
		);
		$repeater->add_control(
			'btn_title3',
			[
				'label'       => __( 'Button Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'btn_link3',
			[
				'label' => __( 'Button Url', 'archway' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$this->add_control(
			'slides_v3',
			[
				'label'                 => __('Add Slider Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '3', ],
			]
		);
		
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Main Heading', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'condition' => [ 'layout_control' => '4', ],
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Main Heading', 'archway' ),
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_img4',
			[
				'label' => esc_html__('Slide BG Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_sub_title4',
			[
				'label'       => __( 'Sub Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_title4',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'btn_link4',
			[
				'label' => __( 'Button Url', 'archway' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$this->add_control(
			'slides_v4',
			[
				'label'                 => __('Add Slider Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '4', ],
			]
		);
		
				
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_img5',
			[
				'label' => esc_html__('Slide BG Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_sub_title5',
			[
				'label'       => __( 'Sub Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_title5',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);		
		$repeater->add_control(
			'btn_link5',
			[
				'label' => __( 'Button Url', 'archway' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$repeater->add_control(
			'block_tag5',
			[
				'label'       => __( 'Category', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Category', 'archway' ),
			]
		);
		$this->add_control(
			'slides_v5',
			[
				'label'                 => __('Add Slider Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '5', ],
			]
		);
		
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_img6',
			[
				'label' => esc_html__('Slide BG Image ', 'archway'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_sub_title6',
			[
				'label'       => __( 'Sub Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_title6',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'btn_link6',
			[
				'label' => __( 'Button Url', 'archway' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$this->add_control(
			'slides_v6',
			[
				'label'                 => __('Add Slider Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => ['6', '7'], ],
			]
		);
		$this->end_controls_section();
		
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{
		/**Layout Control Style**/		
		$this->start_controls_section(
			'archway_layout_style',
			[
				'label' => esc_html__('Archway Layout Setting', 'archway'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
            'archway_layout_margin',
            [
                'label'              => __( 'Spacing', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-banner-carousel' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_responsive_control(
            'archway_layout_padding',
            [
                'label'              => __( 'Gapping', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-banner-carousel' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_control(
			'archway_layout_background',
			[
				'label'                 => __( 'Background', 'archway' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'archway_layout_bgtype',
				'label' => __( 'Button Background', 'archway' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .archway-banner-carousel',				
			]
		);
		$this->end_controls_section();	
	}
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
	?>
    
    <?php if($settings['layout_control'] == '7') :?>
    
    <!-- Banner Section -->
    <section class="banner-card-section style-two archway-banner-carousel">        
        <div class="banner-card-carousel owl-theme owl-carousel">
            <?php $i = 1; foreach($settings['slides_v6'] as $key => $item):?>
            <!--Slide Item-->
            <div class="slide-item">
                <div class="image-layer" <?php if($item['block_img6']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($item['block_img6']['id'])); ?>);"<?php } ?>></div>
                <div class="inner-box">
                    <div class="count"><span><?php $i = sprintf('%2d', $i); echo $i; ?></span></div>
                    <div class="cap-box">
                        <div class="cap-inner">
                            <div class="cat"><span><?php echo wp_kses($item['block_sub_title6'], true);?></span></div>
                            <h4><a href="<?php echo esc_url($item['btn_link6']['url']);?>"><?php echo wp_kses($item['block_title6'], true);?></a></h4>
                            <?php if($item['btn_link6']['url']){ ?><div class="link"><a href="<?php echo esc_url($item['btn_link6']['url']);?>"><i class="far fa-plus"></i></a></div><?php } ?>                            
                        </div>
                    </div>
                </div>
            </div>
            <?php $i++; endforeach;?>
        </div>
    </section>
    <!--End Banner Section -->
    
    <?php elseif($settings['layout_control'] == '6') :?>
    
    <!-- Banner Section -->
    <section class="banner-card-section archway-banner-carousel">        
        <div class="banner-card-carousel owl-theme owl-carousel">
            <?php $i = 1; foreach($settings['slides_v6'] as $key => $item):?>
            <!--Slide Item-->
            <div class="slide-item">
                <div class="image-layer" <?php if($item['block_img6']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($item['block_img6']['id'])); ?>);"<?php } ?>></div>
                <div class="inner-box">
                    <div class="count"><span><?php $i = sprintf('%2d', $i); echo $i; ?></span></div>
                    <div class="cap-box">
                        <div class="cap-inner">
                            <div class="cat"><span><?php echo wp_kses($item['block_sub_title6'], true);?></span></div>
                            <h4><a href="<?php echo esc_url($item['btn_link6']['url']);?>"><?php echo wp_kses($item['block_title6'], true);?></a></h4>
                            <?php if($item['btn_link6']['url']){ ?><div class="link"><a href="<?php echo esc_url($item['btn_link6']['url']);?>"><i class="far fa-plus"></i></a></div><?php } ?>                            
                        </div>
                    </div>
                </div>
            </div>
            <?php $i++; endforeach;?>
        </div>
    </section>
    <!--End Banner Section -->
    
	<?php elseif($settings['layout_control'] == '5') :?>
    
    <!-- Creative Carousel Section -->
    <section class="creative-carousel-section archway-banner-carousel">
        <main>
            <div class="revealer">
                <div class="revealer__inner"></div>
            </div>
            <div class="grid grid--slideshow">
                <?php $i = 1; foreach($settings['slides_v5'] as $key => $item):?>
                <figure class="grid__item grid__item--slide">
                    <span class="number"><?php $i = sprintf('%02d', $i); echo $i; ?></span>
                    <div class="img-wrap">
                        <div class="img" <?php if($item['block_img5']['id']){ ?>style="background-image: url(<?php echo esc_url(wp_get_attachment_url($item['block_img5']['id'])); ?>);"<?php } ?>></div>
                        <div class="cat"><span><?php echo wp_kses($item['block_sub_title5'], true);?></span></div>
                        <?php if($item['block_img5']['id']){ ?>
                        <div class="zoom-link"><a href="<?php echo esc_url(wp_get_attachment_url($item['block_img5']['id'])); ?>" class="lightbox-image"><span class="icon far fa-plus"></span></a></div>
                    	<?php } ?>
                    </div>
                    <figcaption class="caption"><h3><a href="<?php echo esc_url($item['btn_link5']['url']);?>"><?php echo wp_kses($item['block_title5'], true);?></a></h3></figcaption>
                </figure>
                <?php $i++; endforeach;?> 
                <div class="titles-wrap">
                    <div class="grid grid--titles">
                        <?php foreach($settings['slides_v5'] as $key => $item):?>
                        <h3 class="grid__item grid__item--title"><?php echo wp_kses($item['block_tag5'], true);?></h3>
                        <?php endforeach;?>
                    </div>
                </div>
                <div class="grid grid--interaction">
                    <div class="grid__item grid__item--cursor grid__item--left"></div>
                    <div class="grid__item grid__item--cursor grid__item--center"></div>
                    <div class="grid__item grid__item--cursor grid__item--right"></div>
                </div>
            </div>
        </main>
    </section>
    <!--End Section -->
    
    <?php elseif($settings['layout_control'] == '4') :?>
    
    <!-- Banner Section -->
    <section class="banner-vertical-section archway-banner-carousel">
        <?php if($settings['heading']){ ?>
        <div class="auto-container">
            <div class="big-title">
                <h2><span><?php echo wp_kses($settings['heading'], true);?></span></h2>
            </div>
        </div>
        <?php } ?>
        <div class="banner-vertical-carousel owl-theme owl-carousel">
            <?php foreach($settings['slides_v4'] as $key => $item):?>
            <!--Slide Item-->
            <div class="slide-item">
                <!--Block-->
                <div class="s-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <?php if($item['block_img4']['id']){ ?>
                            <div class="image"><a href="<?php echo esc_url(wp_get_attachment_url($item['block_img4']['id'])); ?>" class="lightbox-image"><img src="<?php echo esc_url(wp_get_attachment_url($item['block_img4']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>"></a></div>
                            <?php } ?>
                            <div class="cat"><span><?php echo wp_kses($item['block_sub_title4'], true);?></span></div>
                            <?php if($item['block_img4']['id']){ ?>
                            <div class="link"><a href="<?php echo esc_url(wp_get_attachment_url($item['block_img4']['id'])); ?>" class="lightbox-image"><span class="icon far fa-plus"></span></a></div>
                            <?php } ?>
                        </div>
                        <div class="lower-box">
                            <h3><a href="<?php echo esc_url($item['btn_link4']['url']);?>"><?php echo wp_kses($item['block_title4'], true);?></a></h3>
                        </div>
                    </div>
                </div>
            </div>
            <?php endforeach;?>
        </div>
    </section>
    <!--End Banner Section -->
    
	<?php elseif($settings['layout_control'] == '3') :?>
	
    <!-- Project Two -->
	<section class="project-two archway-banner-carousel">
		<div class="inner-container row clearfix">
			<?php $i = 1; $count = 1; foreach($settings['slides_v3'] as $key => $item):?>
			<!-- Project Block Two -->
			<div class="project-block_two hpt-offer-1-item-single <?php if($count == 1) echo 'active';?>">
				<div class="project-block_two-inner">
                    <div class="post-number"><?php $i = sprintf('%02d', $i); echo $i; ?></div>
                    <div class="post-title"><?php echo wp_kses($item['block_title3'], true);?> <?php if($item['block_sub_title3']){ ?><span> \ &ensp; &ensp; <?php echo wp_kses($item['block_sub_title3'], true);?></span><?php } ?></div>
					<div class="project-block_two-image">
						<?php if($item['block_img3']['id']){ ?>
                        <img src="<?php echo esc_url(wp_get_attachment_url($item['block_img3']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>" />
                        <?php } ?>
						<div class="project-block_two-content">
                            <h1 class="project-block_two-heading"><a href="<?php echo esc_url($item['btn_link3']['url']);?>"><?php echo wp_kses($item['block_title3'], true);?></a></h1>
                            <div class="project-block_two-text"><?php echo wp_kses($item['block_text3'], true);?></div>
							<?php if($item['btn_title3']){ ?>
                            <div class="link-box">
                                <a href="<?php echo esc_url($item['btn_link3']['url']);?>" class="theme-btn btn-style-one"><span class="btn-box"><span class="btn-txt"><?php echo wp_kses($item['btn_title3'], true);?></span><i class="btn-arrow fal fa-arrow-right"></i></span></a>
                            </div>
                            <?php } ?>
						</div>
					</div>
				</div>
			</div>
			<?php $i++; $count++; endforeach;?>			
		</div>
	</section>
	<!-- End Project Two -->
    
	<?php elseif($settings['layout_control'] == '2') :?>
    
    <!-- Banner Section -->
    <section class="banner-interact archway-banner-carousel">        
        <div class="banner-inter-carousel owl-theme owl-carousel">
            <?php $i = 1; foreach($settings['slides_v2'] as $key => $item):?>
            <!--Slide Item-->
            <div class="slide-item">
                <div class="bg-layer" <?php if($item['block_img2']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($item['block_img2']['id'])); ?>);"<?php } ?>></div>
                <?php if($item['block_img31']['id']){ ?><div class="img-thumb left-thumb"><img src="<?php echo esc_url(wp_get_attachment_url($item['block_img31']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>"></div><?php } ?>
                <?php if($item['block_img32']['id']){ ?><div class="img-thumb right-thumb"><img src="<?php echo esc_url(wp_get_attachment_url($item['block_img32']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>"></div><?php } ?>
                <div class="content-container">
                    <?php if($item['block_img33']['id']){ ?><div class="img-thumb mid-thumb"><img src="<?php echo esc_url(wp_get_attachment_url($item['block_img33']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>"></div><?php } ?>
                    <div class="image-layer" <?php if($item['block_img34']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($item['block_img34']['id'])); ?>);"<?php } ?>></div>
                    <h1><span class="outlined"><?php echo wp_kses($item['block_title2'], true) ;?></span></h1>
                    <div class="cat"><span><?php echo wp_kses($item['block_sub_title2'], true) ;?></span></div>
                    <div class="text"><?php echo wp_kses($item['block_text2'], true) ;?></div>
                    <div class="slide-num"><span class="num active-num"><?php $i = sprintf('%02d', $i); echo $i; ?></span><span class="num total-num"><?php esc_html_e('04', 'archway'); ?></span></div>
                </div>
            </div>
            <?php $i++; endforeach;?>
        </div>
    </section>
    <!--End Banner Section -->
     
    <?php else :?>
    
    <!-- Banner Section -->
    <section class="banner-full archway-banner-carousel">        
        <div class="banner-full-carousel owl-theme owl-carousel">
           	<?php $i = 1; foreach($settings['slides'] as $key => $item):?>
            <!--Slide Item-->
            <div class="slide-item">
                <div class="image-layer" <?php if($item['block_img']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($item['block_img']['id'])); ?>);"<?php } ?>></div>
                <div class="content-box">
                    <div class="cat"><span><?php echo wp_kses($item['block_sub_title'], true) ;?></span></div>
                    <div class="slide-num"><span class="num active-num"><?php $i = sprintf('%02d', $i); echo $i; ?></span><span class="num total-num"><?php esc_html_e('03', 'archway'); ?></span></div>
                    <div class="content">
                        <div class="inner">
                            <h1><?php echo wp_kses($item['block_title'], true) ;?></h1>
                        </div>
                    </div>
                </div>
            </div>
            <?php $i++; endforeach;?>
        </div>
    </section>
    <!--End Banner Section -->
       
    <?php endif; ?>    
    <?php
    }
}