<?php

namespace ARCHWAYPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Blog_Post extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'archway_blog_post';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Archway Blog Post', 'archway' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-grid';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'archway' ];
	}	
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'blog_post',
			[
				'label' => esc_html__( 'Blog Post', 'archway' ),
			]
		);
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'archway'),
					'2' => esc_html__( 'Style Two ', 'archway'),
				),
			]
		);
		
		$this->add_control(
			'post_date',
			[
				'label'       => __( 'Date', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'condition'   => ['layout_control' => ['2'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Date', 'archway' ),
			]
		);
		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		
		$this->add_control(
			'btn_link',
			[
				  'label' => __( 'Button Url', 'archway' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		
		$this->add_control(
			'image',
			[
				'label' => __( 'Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,
				'condition'   => ['layout_control' => ['2'], ],
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		
		$this->add_control(
            'date',
            [
                'label'        => esc_html__( 'Show Date', 'archway' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'archway' ),
                'label_off'    => esc_html__( 'Off', 'archway' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );
		$this->add_control(
            'cat',
            [
                'label'        => esc_html__( 'Show Category', 'archway' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'archway' ),
                'label_off'    => esc_html__( 'Off', 'archway' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'archway' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'archway' ),
					'title'      => esc_html__( 'Title', 'archway' ),
					'menu_order' => esc_html__( 'Menu Order', 'archway' ),
					'rand'       => esc_html__( 'Random', 'archway' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'archway' ),
					'ASC'  => esc_html__( 'ASC', 'archway' ),
				),
			]
		);
		$this->add_control(
            'query_category', 
			[
			  'type' => Controls_Manager::SELECT,
			  'label' => esc_html__('Category', 'archway'),
			  'label_block' => true,
			  'options' => get_blog_categories()
			]
		);
		$this->add_control(
			'show_pagination',
			[
				'label'       => __( 'Enable/Disable Pagination Style', 'archway' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'archway' ),
				'label_off' => __( 'Hide', 'archway' ),
				'condition' => [ 'layout_control'      => '2', ],
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->end_controls_section();
		
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{
				
		/**Layout Control Style**/		
		$this->start_controls_section(
			'archway_layout_style',
			[
				'label' => esc_html__('Archway Layout Setting', 'archway'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
            'archway_layout_margin',
            [
                'label'              => __( 'Spacing', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-blog-section' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_responsive_control(
            'archway_layout_padding',
            [
                'label'              => __( 'Gapping', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-blog-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_control(
			'archway_layout_background',
			[
				'label'                 => __( 'Background', 'archway' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'archway_layout_bgtype',
				'label' => __( 'Button Background', 'archway' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .archway-blog-section',				
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		$date = $settings[ 'date' ];
		$cat = $settings[ 'cat' ];
		
        $paged = get_query_var('paged');
		$paged = archway_set($_REQUEST, 'paged') ? esc_attr($_REQUEST['paged']) : $paged;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-archway' );
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => archway_set( $settings, 'query_number' ),
			'orderby'        => archway_set( $settings, 'query_orderby' ),
			'order'          => archway_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if( archway_set( $settings, 'query_category' ) ) $args['category_name'] = archway_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{ ?>      
        
        <?php if($settings['layout_control'] == '2'): ?>
        
        <!-- Blog One -->
        <section class="blog-one archway-blog-section">
            <div class="auto-container">
                <div class="inner-container">                   
                    <?php if($settings['post_date'] || $settings['title'] || $settings['image']['id']){ ?>
                    <!-- News Block One -->
                    <div class="news-block_one">
                        <div class="inner-box">
                            <?php if($settings['post_date'] || $settings['title']){ ?>
                            <div class="content">
                                <?php if($settings['post_date']){ ?><div class="title"><?php echo wp_kses($settings['post_date'], true);?></div><?php } ?>
                                <?php if($settings['title']){ ?><h2><a href="<?php echo esc_url($settings['btn_link']['url']); ?>"><?php echo wp_kses($settings['title'], true);?></a></h2><?php } ?>
                            </div>
                            <?php } ?>
                            <?php if($settings['image']['id']){ ?>
                            <div class="image">
                                <img src="<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" />
                            </div>
                            <?php } ?>
                        </div>
                    </div>
                    <?php } ?>    
                    <div class="row clearfix">
    					<?php 
							$count = 1;
							while ( $query->have_posts() ) : $query->the_post();                    
						?>
						<?php if($count % 2) { ?>
						<!--Block-->
						<div class="ai-block alternate col-lg-4 col-md-6 col-sm-12">
							<div class="inner-box">
								<div class="cap-box">
									<?php if( $date == 'yes' || $cat == 'yes' ){?>
									<div class="info"><?php if( $date == 'yes' ){?><?php echo get_the_date( ); ?><?php };?> <?php if( $cat == 'yes' ){?>/ <?php the_category(' '); ?><?php };?></div>
									<?php };?>
									<div class="s-title"><h3><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3></div>
								</div>
								<div class="image-box">
									<div class="image"><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('archway_220x220'); ?></a></div>
								</div>
							</div>
						</div>
						<?php } else { ?>
						<!--Block-->
						<div class="ai-block col-lg-4 col-md-6 col-sm-12">
							<div class="inner-box">
								<div class="image-box">
									<div class="image"><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('archway_480x320'); ?></a></div>
								</div>
								<div class="cap-box">
									<?php if( $date == 'yes' || $cat == 'yes' ){?>
									<div class="info"><?php if( $date == 'yes' ){?><?php echo get_the_date( ); ?><?php };?> <?php if( $cat == 'yes' ){?>/ <?php the_category(' '); ?><?php };?></div>
									<?php };?>
									<div class="s-title"><h3><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3></div>
								</div>
							</div>
						</div>
						<?php } ?>
						<?php $count++; endwhile; ?>    					    
                    </div>
    				<?php if($settings['show_pagination']) { ?>
                    <div class="pagination-outer">
                        <div class="pagination">
                        	<?php archway_the_pagination2(array('total'=>$query->max_num_pages, 'next_text' => '<span class="fas fa-arrow-right"></span>', 'prev_text' => '<span class="fas fa-arrow-left"></span>')); ?>
                        </div>
                    </div>
                    <?php } ?>    
                </div>
            </div>
        </section>
        <!-- End Blog One -->
        
        <?php else :?>
        
        <!--Architectural Insights Section-->
        <section class="ai-section no-pad-top archway-blog-section">
            <?php if($settings['title'] || $settings['btn_link']['url']){ ?>
            <div class="auto-container">
                <div class="title-box clearfix">
                    <?php if($settings['title']){ ?><h2><?php echo wp_kses($settings['title'], true);?></h2><?php } ?>
                    <?php if($settings['btn_link']['url']){ ?><div class="link-box"><a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="theme-btn"><i class="arrow fal fa-arrow-right"></i></a></div><?php } ?>
                </div>
            </div>
            <?php } ?>
            <div class="carousel-box">
                <div class="ai-carousel owl-theme owl-carousel">
                    <?php 
                        $count = 1;
                        while ( $query->have_posts() ) : $query->the_post();                    
                    ?>
                    <?php if($count % 2) { ?>
                    <!--Block-->
                    <div class="ai-block alternate">
                        <div class="inner-box">
                            <div class="cap-box">
                                <?php if( $date == 'yes' || $cat == 'yes' ){?>
                                <div class="info"><?php if( $date == 'yes' ){?><?php echo get_the_date( ); ?><?php };?> <?php if( $cat == 'yes' ){?>/ <?php the_category(' '); ?><?php };?></div>
                                <?php };?>
                                <div class="s-title"><h3><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3></div>
                            </div>
                            <div class="image-box">
                                <div class="image"><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('archway_220x220'); ?></a></div>
                            </div>
                        </div>
                    </div>
                    <?php } else { ?>
                    <!--Block-->
                    <div class="ai-block">
                        <div class="inner-box">
                            <div class="image-box">
                                <div class="image"><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('archway_480x320'); ?></a></div>
                            </div>
                            <div class="cap-box">
                                <?php if( $date == 'yes' || $cat == 'yes' ){?>
                                <div class="info"><?php if( $date == 'yes' ){?><?php echo get_the_date( ); ?><?php };?> <?php if( $cat == 'yes' ){?>/ <?php the_category(' '); ?><?php };?></div>
                                <?php };?>
                                <div class="s-title"><h3><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3></div>
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <?php $count++; endwhile; ?>
                </div>
            </div>
        </section>
       
       <?php endif; ?>               
        <?php }
		wp_reset_postdata();
	}

}
