<?php namespace ARCHWAYPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Faqs extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'archway_faqs';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Archway Faqs', 'archway' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-accordion';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'archway' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'faqs',
			[
				'label' => esc_html__( 'Faqs', 'archway' ),
			]
		);
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'archway'),
					'2' => esc_html__( 'Style Two ', 'archway'),
				),
			]
		);
		$this->add_control(
			'shape_image',
			[
				'label' => __( 'Shape Image', 'archway' ),
				'condition' => [ 'layout_control' => '1', ],
				'type' => Controls_Manager::MEDIA,				
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'about_image',
			[
				'label' => __( 'About Image', 'archway' ),
				'condition' => [ 'layout_control' => '1', ],
				'type' => Controls_Manager::MEDIA,				
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		
		$this->add_control(
			'sub_title',
			[
				'label'       => __( 'Sub Title', 'archway' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'layout_control' => '1', ],				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'archway' ),
			]
		);
		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_title',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);		
		$repeater->add_control(
			'block_text',
			[
				'label'       => __( 'Text', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'archway' ),
			]
		);
		$this->add_control(
			'history_tab',
			[
				'label'                 => __('Add Tab Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '1', ],
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_title2',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_image',
			[
				'label' => __( 'Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,				
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_text2',
			[
				'label'       => __( 'Text', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_text3',
			[
				'label'       => __( 'Text', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'archway' ),
			]
		);
		$this->add_control(
			'history_tab_v2',
			[
				'label'                 => __('Add Tab Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '2', ],
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_image2',
			[
				'label' => __( 'Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,				
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_title3',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_image3',
			[
				'label' => __( 'Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,				
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_text4',
			[
				'label'       => __( 'Text', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'archway' ),
			]
		);
		$this->add_control(
			'faq_tab',
			[
				'label'                 => __('Add Accordian Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '2', ],
			]
		);		
		$this->end_controls_section();
	
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{
		
		/**Layout Control Style**/		
		$this->start_controls_section(
			'archway_layout_style',
			[
				'label' => esc_html__('Archway Layout Setting', 'archway'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
            'archway_layout_margin',
            [
                'label'              => __( 'Spacing', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-accordian-section' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_responsive_control(
            'archway_layout_padding',
            [
                'label'              => __( 'Gapping', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-accordian-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_control(
			'archway_layout_background',
			[
				'label'                 => __( 'Background', 'archway' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'archway_layout_bgtype',
				'label' => __( 'Button Background', 'archway' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .archway-accordian-section',				
			]
		);
		$this->end_controls_section();		
		
		/**Sub Title Style**/
		$this->start_controls_section(
			'subtitle_style',
			[
				'label' => esc_html__('SUBTITLE STYLE SETTING', 'archway'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Sub Title
		$this->add_control(
			'show_subtitle_style',
			[
				'label'       => __( 'ON/OFF Sub Title Style', 'archway' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'archway' ),
				'label_off' => esc_html__( 'Hide', 'archway' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);		
		$this->add_control(
			'subtitle_background',
			[
				'label'                 => __( 'Background', 'archway' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_subtitle_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'subtitle_bgtype',
				'label' => __( 'Sub Title Background', 'archway' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .archway-banner-subtitle',	
				'condition'             => [
					'show_subtitle_style'    => 'yes',
				]			
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'label' => __('Sub Title Typography', 'archway'),
                'selector' => 
                    '{{WRAPPER}} .archway-banner-subtitle',                 
                'separator' => 'before',
				'condition'             => [
					'show_subtitle_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'subtitle_color',
            [
                'label' => __('Sub Title Color', 'archway'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .archway-banner-subtitle' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_subtitle_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();	
		
		/**Title Style**/
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__('TITLE STYLE SETTING', 'archway'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Title
		$this->add_control(
			'show_title_style',
			[
				'label'       => __( 'ON/OFF Title Style', 'archway' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'archway' ),
				'label_off' => esc_html__( 'Hide', 'archway' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'archway' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .archway-banner-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
				'condition'             => [
					'show_title_style'    => 'yes',
				]
            ]
        );
		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'archway' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .archway-banner-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
				'condition'             => [
					'show_title_style'    => 'yes',
				]
            ]
        );
		
		$this->add_control(
			'title_background',
			[
				'label'                 => __( 'Background', 'archway' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_title_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bgtype',
				'label' => __( 'Title Background', 'archway' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .archway-banner-title',	
				'condition'             => [
					'show_title_style'    => 'yes',
				]			
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __('Title Typography', 'archway'),
                'selector' => 
                    '{{WRAPPER}} .archway-banner-title',                 
                'separator' => 'before',
				'condition'             => [
					'show_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'title_color',
            [
                'label' => __('Title Color', 'archway'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .archway-banner-title' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_title_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();				
	}

	/**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
	?>
    
    <?php if($settings['layout_control'] == '2') :?>
    
    <!-- Building One -->
    <section class="building-one archway-accordian-section">
        <div class="auto-container">
            <?php if($settings['title']) { ?>
            <div class="sec-title">
                <h2 class="archway-banner-title"><?php echo wp_kses($settings['title'], true);?></h2>
            </div>
            <?php } ?>
            <div class="row clearfix">
                <!-- Column -->
                <div class="column col-lg-6 col-md-12 col-sm-12">
                    <div class="tabs-box building-tabs">
                        <ul class="tab-buttons clearfix">
                            <?php 
								$count = 1;
								foreach($settings['history_tab_v2'] as $key => $item):
							?>
							<li class="tab-btn <?php if($count == 1) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($count);?>"><span><?php echo wp_kses($item['block_title2'], true) ;?></span></li>
							<?php $count++; endforeach;?>                            
                        </ul>
                        <div class="tabs-content">
                            <?php 
								$counts = 1;
								foreach($settings['history_tab_v2'] as $key => $item):
							?>							
                            <!--Tab-->
                            <div class="tab <?php if($counts == 1) echo 'active-tab';?>" id="tab-<?php echo esc_attr($counts);?>">
                                <div class="content">
                                    <div class="upper-box">
                                        <?php if($item['block_image']['id']){ ?>
                                        <div class="image">
                                            <img src="<?php echo esc_url(wp_get_attachment_url($item['block_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" />
                                        </div>
                                        <?php } ?>
                                        <p><?php echo wp_kses($item['block_text2'], true) ;?></p>
                                    </div>
                                    <p><?php echo wp_kses($item['block_text3'], true) ;?></p>
                                </div>
                            </div>
                            <?php $counts++; endforeach;?>
                        </div>
                    </div>
                </div>

                <!-- Column -->
                <div class="column col-lg-6 col-md-12 col-sm-12">
                    <!-- Accordion Box -->
					<ul class="accordion-box">
						<?php 
							$g = 1;
							foreach($settings['faq_tab'] as $key => $item):
						?>	
						<!-- Block -->
						<li class="accordion block <?php if($g == 1) echo 'active-block';?>">
							<?php if($item['block_image2']['id'] || $item['block_title3']){ ?>
                            <div class="acc-btn <?php if($g == 1) echo 'active';?>"><div class="icon-outer"><span class="icon"><img src="<?php echo esc_url(wp_get_attachment_url($item['block_image2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" /></span></div><?php echo wp_kses($item['block_title3'], true) ;?></div>
							<?php } ?>
                            <div class="acc-content <?php if($g == 1) echo 'current';?>">
								<div class="content">
                                    <?php if($item['block_image3']['id']){ ?>
                                    <div class="image">
                                        <img src="<?php echo esc_url(wp_get_attachment_url($item['block_image3']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway');?>" />
                                    </div>
                                    <?php } ?>
									<div class="text"><?php echo wp_kses($item['block_text4'], true) ;?></div>
								</div>
							</div>
						</li>
						<?php $g++; endforeach;?>
                    </ul>
                </div>

            </div>
        </div>
    </section>
    <!-- End Building One -->
    
    <?php else: ?>
    
    <!--About Section-->
    <section class="about-two archway-accordian-section">
        <div class="image-layer" <?php if($settings['shape_image']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($settings['shape_image']['id'])); ?>);"<?php } ?>></div>
        <div class="auto-container">
            <?php if($settings['sub_title'] || $settings['title']) { ?>
            <div class="sec-title light centered">
                <?php if($settings['sub_title']) { ?><div class="subtitle archway-banner-subtitle"><span><?php echo wp_kses($settings['sub_title'], true);?></span></div><?php } ?>
                <?php if($settings['title']) { ?><h2 class="archway-banner-title"><?php echo wp_kses($settings['title'], true);?></h2><?php } ?>
            </div>
            <?php } ?>
            <div class="row clearfix">
                <!--Text Col-->
                <div class="text-col col-xl-7 col-lg-7 col-md-12 col-sm-12">
                    <div class="inner wow fadeInRight" data-wow-duration="1500ms" data-wow-delay="0ms">
                        <div class="tabs-box about-tabs">
                            <ul class="tab-buttons clearfix">
                                <?php 
									$count = 1;
									foreach($settings['history_tab'] as $key => $item):
								?>
                                <li class="tab-btn <?php if($count == 1) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($count);?>"><span><?php echo wp_kses($item['block_title'], true) ;?></span></li>
                                <?php $count++; endforeach;?>
                            </ul>
                            <div class="tabs-content">
                                <?php 
									$counts = 1;
									foreach($settings['history_tab'] as $key => $item):
								?>
                                <!--Tab-->
                                <div class="tab <?php if($counts == 1) echo 'active-tab';?>" id="tab-<?php echo esc_attr($counts);?>">
                                    <div class="text">
                                        <?php echo wp_kses($item['block_text'], true) ;?>
                                    </div>
                                </div>
                                <?php $counts++; endforeach;?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php if($settings['about_image']['id']){ ?>
                <!--Image Col-->
                <div class="image-col col-xl-5 col-lg-5 col-md-12 col-sm-12">
                    <div class="inner wow fadeInLeft" data-wow-duration="1500ms" data-wow-delay="0ms">
                        <div class="image"><img src="<?php echo esc_url(wp_get_attachment_url($settings['about_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>"></div>
                    </div>
                </div>
                <?php } ?>
            </div>
        </div>
    </section>
    
    <?php endif; ?>  
	<?php 
	}

}
		