<?php namespace ARCHWAYPLUGIN\Element;
use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;
/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Form extends Widget_Base {
    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'archway_form';
    }
    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Archway Form', 'archway' );
    }
    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-form-horizontal';
    }
    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'archway' ];
    }
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'form',
            [
                'label' => esc_html__( 'Form', 'archway' ),
            ]
        );		
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'icons',
			[
				'label' => esc_html__('Enter The icons', 'archway'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
			]
			
		);
		$repeater->add_control(
			'block_title',
			[
				'label'       => __( 'Block Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Block Title Here', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_info',
			[
				'label'       => __( 'Contact Info', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Contact Info Here', 'archway' ),
			]
		);
		$this->add_control(
			'info',
			[
				'label'                 => __('Add Contact Info Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
			]
		);	
		
		$this->add_control(
			'form_title',
			[
				'label'       => __( 'Form Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Form Title Here', 'archway' ),
			]
		);			
		$this->add_control(
            'cf7_shortocde',
            [
                'label' => esc_html__('Select Contact Form 7', 'archway'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => get_contact_form_7_list(),
            ]
        );	
		
		$this->add_control(
			'social_title',
			[
				'label'       => __( 'Social Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Social Title Here', 'archway' ),
			]
		);
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'social_icon_title',
			[
				'label'       => __( 'Social Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Social Title Here', 'archway' ),
			]
		);
		$repeater->add_control(
			'social_link',
			[
				'label' => __( 'Social Url', 'archway' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$this->add_control(
			'social',
			[
				'label'                 => __('Add Social Media', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'address_city',
			[
				'label'       => __( 'Address Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Address Title Here', 'archway' ),
			]
		);
		$repeater->add_control(
			'address_street',
			[
				'label'       => __( 'Address', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Address Here', 'archway' ),
			]
		);
		$this->add_control(
			'address',
			[
				'label'                 => __('Add Address Info Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
			]
		);		
		$this->end_controls_section();		
	}
	
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
	?>
	        
    <!-- Contact One -->
    <section class="contact-one">
        <div class="auto-container">
            <div class="inner-container">
                <div class="clearfix">
					<?php 
						foreach($settings['info'] as $key => $item): 
						$icons = $item[ 'icons' ];
					?>
                    <!-- Info Column -->
                    <div class="info-column col-lg-4 col-md-6 col-sm-12">
                        <div class="inner-column">
                            <?php if($item['block_title']){ ?><div class="title"><span class="icon fa-solid"><?php \Elementor\Icons_Manager::render_icon( $icons ); ?></span> <?php echo wp_kses($item['block_title'], true);?></div><?php } ?>
                            <?php if($item['block_info']){ ?><div class="info"><?php echo wp_kses($item['block_info'], true);?></div><?php } ?>
                        </div>
                    </div>
					<?php endforeach;?>
                </div>
            </div>
            <div class="row clearfix">
                <!-- Column -->
                <div class="form-column col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <?php if($settings['form_title']) {?><h2><?php echo wp_kses($settings['form_title'], true);?></h2><?php };?> 
						<?php if( $settings['cf7_shortocde'] ){?>
                        <!-- Default Form -->
						<div class="contact-form">
							<div id="contact-form">
								<?php echo do_shortcode('[contact-form-7 id="'.esc_attr($settings['cf7_shortocde']).'"]'); ?>
							</div>
						</div>
						<!-- End Default Form -->
						<?php };?>
                    </div>
                </div>
                <!-- Column -->
                <div class="social-column col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <?php if($settings['social_title']) {?><h2><?php echo wp_kses($settings['social_title'], true);?></h2><?php };?> 
                        <ul class="social-links">
                            <?php 
								foreach($settings['social'] as $key => $item):
							?>
                            <?php if($item['social_icon_title'] || $item['social_link']['url']){ ?>
							<li><a href="<?php echo esc_url($item['social_link']['url']);?>"><?php echo wp_kses($item['social_icon_title'], true);?> <span class="arrow fa-solid fa-arrow-right fa-fw"></span></a></li>
							<?php } ?>
							<?php endforeach;?>
                        </ul>
                    </div>
                </div>
				<?php foreach($settings['address'] as $key => $item): ?>
                <?php if($item['address_street'] || $item['address_city']){ ?>
                <!-- Column -->
                <div class="location-column col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <?php if($item['address_city']){ ?><h2><?php echo wp_kses($item['address_city'], true);?></h2><?php } ?>
                        <?php if($item['address_street']){ ?><div class="text"><?php echo wp_kses($item['address_street'], true);?></div>
                        <div class="icon fa-solid fa-location-dot fa-fw"></div><?php } ?>
                    </div>
                </div>
                <?php } ?>
				<?php endforeach;?>
            </div>
        </div>
    </section>
    <!-- End Contact One -->
            
    <?php
    }
}