<?php namespace ARCHWAYPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;
/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Funfact_Box extends Widget_Base {
    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'archway_funfact_box';
    }
    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Archway Funfact Box', 'archway' );
    }
    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-image-box';
    }
    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'archway' ];
    }
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'funfact_box',
            [
                'label' => esc_html__( 'Funfact Box', 'archway' ),
            ]
        );
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'archway'),
					'2' => esc_html__( 'Style Two ', 'archway'),
				),
			]
		);
		$this->add_control(
			'shape_image',
			[
				'label' => __( 'Shape Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,	
				'condition' => [ 'layout_control' => '2', ],			
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);		
		$this->add_control(
			'feature_image',
			[
				'label' => esc_html__( 'Choose Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [	'active' => true,],
				'default' => ['url' => Utils::get_placeholder_image_src(),	],
			]
		);
				
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'archway' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter your title', 'archway' ),
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'counter_start',
			[
				'label' => esc_html__( 'Counter Start', 'archway' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,			
				'placeholder' => esc_html__( 'Enter your Counter Start', 'archway' ),
				'default' => esc_html__( '0', 'archway' ),
			]
		);
		$repeater->add_control(
			'counter_stop',
			[
				'label' => esc_html__( 'Counter Stop', 'archway' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter your Counter Stop', 'archway' ),
				'default' => esc_html__( '45', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_title',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		$repeater->add_control(
			'block_text',
			[
				'label'       => __( 'Text', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'archway' ),
			]
		);
		$this->add_control(
			'funfact',
			[
				'label'                 => __('Add Counter Item', 'archway'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
			]
		);		
		$this->end_controls_section();
		
		//General Style
		$this->start_controls_section(
			'general_style',
			[
				'label' => esc_html__( 'General Setting', 'archway' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
            'general_margin',
            [
                'label'      => esc_html__( 'Margin', 'archway' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .archway-funfact-section' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		$this->add_responsive_control(
            'general_padding',
            [
                'label'      => esc_html__( 'Padding', 'archway' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .archway-funfact-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'general_bgtype',
				'label' => __( 'Background', 'archway' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .archway-funfact-section',				
			]
		);
		$this->end_controls_section();
		
	}
	
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');		
	?>
    
    <?php if($settings['layout_control'] == '2') :?>
    
    <!--About Section-->
    <section class="about-section archway-funfact-section" <?php if($settings['shape_image']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($settings['shape_image']['id'])); ?>);"<?php } ?>>
        <div class="auto-container">
            <div class="row clearfix">
                <!--Text Col-->
                <div class="text-col col-xl-8 col-lg-12 col-md-12 col-sm-12">
                    <div class="inner wow fadeInLeft" data-wow-duration="1500ms" data-wow-delay="0ms">
                        <?php if($settings['title']){ ?><h1><?php echo wp_kses($settings['title'], true ) ;?></h1><?php } ?>
                        <div class="fun-facts">
                            <div class="row clearfix">
                                <?php 
									foreach($settings['funfact'] as $key => $item):
								?>
                                <!--Block-->
                                <div class="fact-block col-lg-6 col-md-12 col-sm-12">
                                    <div class="inner-box">
                                        <div class="count-outer">
                                            <div class="fact-count"><div class="count-box"><span class="count-text" data-stop="<?php echo wp_kses($item['counter_stop'], true ) ;?>" data-speed="3000"><?php echo wp_kses($item['counter_start'], true ) ;?></span></div></div>
                                        </div>
                                        <h4><?php echo wp_kses($item['block_title'], true) ;?></h4>
                                        <div class="text"><?php echo wp_kses($item['block_text'], true) ;?></div>
                                    </div>
                                </div>
                                <?php endforeach;?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php if($settings['feature_image']['id']){ ?>
                <!--Image Col-->
                <div class="image-col col-xl-4 col-lg-6 col-md-10 col-sm-12">
                    <div class="inner wow fadeInRight" data-wow-duration="1500ms" data-wow-delay="0ms">
                        <div class="image-box"><div class="image"><img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>"></div></div>
                    </div>
                </div>
                <?php } ?>
            </div>
        </div>
    </section>
    
    <?php else: ?>
    
    <!--About Section-->
    <section class="about-section archway-funfact-section">
        <div class="auto-container">
            <div class="row clearfix">
                <!--Text Col-->
                <div class="text-col col-xl-8 col-lg-12 col-md-12 col-sm-12">
                    <div class="inner wow fadeInLeft" data-wow-duration="1500ms" data-wow-delay="0ms">
                        <?php if($settings['title']){ ?><h1><?php echo wp_kses($settings['title'], true ) ;?></h1><?php } ?>
                        <div class="fun-facts">
                            <div class="row clearfix">
                                <?php 
									foreach($settings['funfact'] as $key => $item):
								?>
                                <!--Block-->
                                <div class="fact-block col-lg-6 col-md-12 col-sm-12">
                                    <div class="inner-box">
                                        <div class="count-outer">
                                            <div class="fact-count"><div class="count-box"><span class="count-text" data-stop="<?php echo wp_kses($item['counter_stop'], true ) ;?>" data-speed="3000"><?php echo wp_kses($item['counter_start'], true ) ;?></span></div></div>
                                        </div>
                                        <h4><?php echo wp_kses($item['block_title'], true) ;?></h4>
                                        <div class="text"><?php echo wp_kses($item['block_text'], true) ;?></div>
                                    </div>
                                </div>
                                <?php endforeach;?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php if($settings['feature_image']['id']){ ?>
                <!--Image Col-->
                <div class="image-col col-xl-4 col-lg-6 col-md-10 col-sm-12">
                    <div class="inner wow fadeInRight" data-wow-duration="1500ms" data-wow-delay="0ms">
                        <div class="image-box"><div class="image"><img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>"></div></div>
                    </div>
                </div>
                <?php } ?>
            </div>
        </div>
    </section>   
	
    <?php endif; ?>        
    <?php 
    }
}