<?php
namespace ARCHWAYPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Masonary_Projects extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'archway_masonary_projects';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Archway Masonary Projects', 'archway' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-justified';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'archway' ];
	}
		
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'masonary_projects',
			[
				'label' => esc_html__( 'Masonary Projects', 'archway' ),
			]
		);
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'archway'),
					'2' => esc_html__( 'Style Two ', 'archway'),
					'3' => esc_html__( 'Style Three ', 'archway'),
				),
			]
		);
		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'condition' => ['layout_control' => ['2'], ],
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		
		$this->add_control(
			'number',
			[
				'label'   => esc_html__( 'Number of post', 'archway' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 7,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'archway' ),
					'ASC'  => esc_html__( 'ASC', 'archway' ),
				),
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'archway' ),
					'title'      => esc_html__( 'Title', 'archway' ),
					'menu_order' => esc_html__( 'Menu Order', 'archway' ),
					'rand'       => esc_html__( 'Random', 'archway' ),
				),
			]
		);	
		$this->add_control(
			'cat_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'archway' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude categories, etc. by ID with comma separated.', 'archway' ),
			]
		);	
		$this->end_controls_section();
				
    }
	
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		
		$paged = archway_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;
		$this->add_render_attribute( 'wrapper', 'class', 'themeexpo-archway' );
		$args = array(
			'post_type'      => 'project',
			'posts_per_page' => archway_set( $settings, 'number' ),
			'orderby'        => archway_set( $settings, 'query_orderby' ),
			'order'          => archway_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		$terms_array = explode(",",archway_set( $settings, 'cat_exclude' ));
		if(archway_set( $settings, 'cat_exclude' )) $args['tax_query'] = array(array('taxonomy' => 'project_cat','field' => 'id','terms' => $terms_array,'operator' => 'NOT IN',));
		$allowed_tags = wp_kses_allowed_html('post');
		$query = new \WP_Query( $args );
		$t = '';
		$data_filtration = '';
		$data_posts = '';
		if ( $query->have_posts() ) 
		{
		ob_start();
		?>
  
		<?php 
            $count = 0; 
            $fliteration = array();
            while( $query->have_posts() ): $query->the_post();
            global  $post;
            $meta = ''; //printr($meta);
            $meta1 = ''; //_WSH()->get_meta();
            $post_terms = get_the_terms( get_the_id(), 'project_cat');// printr($post_terms); exit();
            foreach( (array)$post_terms as $pos_term ) $fliteration[$pos_term->term_id] = $pos_term;
            $temp_category = get_the_term_list(get_the_id(), 'project_cat', '', ', ');
            
            $post_terms = wp_get_post_terms( get_the_id(), 'project_cat'); 
            $term_slug = '';
            if( $post_terms ) foreach( $post_terms as $p_term ) $term_slug .= $p_term->slug.' ';
        	
			$term_list = wp_get_post_terms(get_the_id(), 'project_cat', array("fields" => "names"));
			$post_thumbnail_id = get_post_thumbnail_id($post->ID);
			$post_thumbnail_url = wp_get_attachment_url( $post_thumbnail_id );
			
       ?>
       	<?php $archway_projects_meta = get_post_meta( get_the_ID(), 'archway_meta_projects', true );?>	
        	
            <?php if($settings['layout_control'] == '3') : ?>
            
            <div class="portfolio-block_one mix all <?php echo esc_attr($term_slug); ?> <?php echo esc_attr($term_slug); ?> <?php if(get_post_meta( get_the_id(), 'project_dimension', true ) == 'extra_width' ) echo 'col-lg-6 col-md-12 col-sm-12'; else echo 'col-lg-3 col-md-6 col-sm-12'; ?>">
                <div class="inner-box">
                    <div class="title"><?php echo implode( ', ', (array)$term_list );?></div>
                    <div class="image">
                        <?php 
							$dimention = get_post_meta( get_the_id(), 'project_dimension', true );
							if($dimention == 'extra_width'){ 
								$size = 'archway_947x532'; 
							} else { 
								$size = 'archway_473x533'; 
							} the_post_thumbnail($size);
						?>
                        <div class="content">
                            <h5><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title();?></a></h5>
                        </div>
                    </div>
                </div>
            </div>
            
			<?php elseif($settings['layout_control'] == '2') : ?>
            
            <!-- PortFolio Block Two -->
            <div class="portfolio-block_two masonry-item col-lg-3 col-md-4 col-sm-6">
                <div class="inner-box">
                    <div class="image">
                        <?php 
							$dimention = get_post_meta( get_the_id(), 'project_dimension', true );
							if($dimention == 'extra_larg_height'){ 
								$size = 'archway_353x529'; 
							} elseif($dimention == 'extra_height'){ 
								$size = 'archway_353x494'; 
							} elseif($dimention == 'normal_height'){ 
								$size = 'archway_353x378'; 
							}  elseif($dimention == 'normal_width_height'){ 
								$size = 'archway_353x334'; 
							} else { 
								$size = 'archway_353x235'; 
							} the_post_thumbnail($size);
						?>
                        <div class="overlay-box">
                            <div class="overlay-box_inner">
                                <div class="link-box"><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>" class="theme-btn btn-style-one"><span class="btn-box"><span class="btn-txt"><?php esc_html_e('view Project', 'archway');?></span><i class="btn-arrow fal fa-arrow-right"></i></span></a></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php else: ?>
            
            <!-- Portfolio Block One -->
            <div class="portfolio-block_one masonry-item all <?php echo esc_attr($term_slug); ?> <?php if(get_post_meta( get_the_id(), 'project_dimension', true ) == 'extra_width_height' ) echo 'col-lg-6 col-md-12 col-sm-12'; elseif(get_post_meta( get_the_id(), 'project_dimension', true ) == 'extra_width' ) echo 'col-lg-6 col-md-12 col-sm-12'; else echo 'col-lg-3 col-md-6 col-sm-12'; ?>">
                <div class="inner-box">
                    <div class="title"><?php echo implode( ', ', (array)$term_list );?></div>
                    <div class="image">
                        <?php 
							$dimention = get_post_meta( get_the_id(), 'project_dimension', true );
							if($dimention == 'extra_width_height'){ 
								$size = 'archway_932x1045'; 
							} elseif($dimention == 'extra_width'){ 
								$size = 'archway_932x523'; 
							} else { 
								$size = 'archway_466x524'; 
							} the_post_thumbnail($size);
						?>
                        <div class="content">
                            <h5><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title();?></a></h5>
                        </div>
                    </div>
                </div>
            </div>
            
            <?php endif; ?>           
                  
       <?php endwhile;?>
            <?php wp_reset_postdata();
            $data_posts = ob_get_contents();
            ob_end_clean();
            
            ob_start();?>
            
            <?php $terms = get_terms(array('project_cat')); ?>
    			
                <?php if($settings['layout_control'] == '3') : ?>
                
                <!-- Portfolio Three -->
                <section class="portfolio-three">
                    <div class="auto-container">
                        <div class="mixitup-gallery">
                            <div class="filters clearfix">                                
                                <ul class="filter-tabs filter-btns clearfix">
                                    <li class="active filter" data-role="button" data-filter="all"><?php esc_attr_e('All', 'archway');?></li>
                                    <?php foreach( $fliteration as $t ): ?>
                                    <li class="filter" data-role="button" data-filter=".<?php echo esc_attr(archway_set( $t, 'slug' )); ?>"><?php echo archway_set( $t, 'name'); ?></li>
                                    <?php endforeach;?>                                    
                                </ul>                                
                            </div>                            
                            <div class="filter-list row clearfix">            
                                <?php echo wp_kses($data_posts, true); ?>            					            
                            </div>
                        </div>
                    </div>
                </section>
                <!-- End Portfolio Three -->
                
                <?php elseif($settings['layout_control'] == '2') : ?>
                
                <!-- Portfolio Four -->
                <section class="portfolio-four">
                    <div class="auto-container">
                        <?php if($settings['title']) { ?>
                        <div class="title-box text-center">
                            <h2><?php echo wp_kses($settings['title'], true);?></h2>
                        </div>
                        <?php } ?>
                        <div class="masonry-items-container row clearfix">
                            <?php echo wp_kses($data_posts, true); ?>            				            
                        </div>
                    </div>
                </section>
                <!-- End Portfolio Four -->
                
                <?php else: ?>
                
                <!-- Portfolio Two -->
                <section class="portfolio-two">
                    <div class="auto-container">
                        <!--Isotope Galery-->
                        <div class="sortable-masonry">                            
                            <!-- Filter -->
                            <div class="filters clearfix">                                
                                <ul class="filter-tabs filter-btns clearfix">
                                    <li class="active filter" data-role="button" data-filter=".all"><?php esc_attr_e('Home', 'archway');?></li>
                                    <?php foreach( $fliteration as $t ): ?>
                                    <li class="filter" data-role="button" data-filter=".<?php echo esc_attr(archway_set( $t, 'slug' )); ?>"><?php echo archway_set( $t, 'name'); ?></li>
                                    <?php endforeach;?>
                                </ul>                                
                            </div>                            
                            <div class="items-container clearfix">
            					<?php echo wp_kses($data_posts, true); ?>         					
                            </div>                            
                        </div>
                    </div>
                </section>
                <!-- End Portfolio Two -->
                
  				<?php endif; ?>
       <?php }
	}
}
		