<?php namespace ARCHWAYPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Project_Grid extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'archway_Project_grid';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Archway Project Grid', 'archway' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-banner';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'archway' ];
    }
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'project_grid',
            [
                'label' => esc_html__( 'Project Grid', 'archway' ),
            ]
        );
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'archway'),
					'2' => esc_html__( 'Style Two ', 'archway'),
				),
			]
		);
		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'archway' ),
				'type'        => Controls_Manager::TEXTAREA,
				'condition' => ['layout_control' => ['1'], ],
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'archway' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => ['layout_control' => ['1'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'archway' ),
			]
		);
		
		$this->add_control(
			'btn_link',
			[
				  'label' => __( 'Button Url', 'archway' ),
				  'type' => Controls_Manager::URL,
				  'condition' => ['layout_control' => ['1'], ],
				  'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				  'show_external' => true,
				  'default' => [
				    'url' => '',
				    'is_external' => true,
				    'nofollow' => true,
				  ],
			 ]
		);
		
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'archway' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'archway' ),
					'title'      => esc_html__( 'Title', 'archway' ),
					'menu_order' => esc_html__( 'Menu Order', 'archway' ),
					'rand'       => esc_html__( 'Random', 'archway' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'archway' ),
					'ASC'  => esc_html__( 'ASC', 'archway' ),
				),
			]
		);
		$this->add_control(
            'query_category', 
			[
			  'type' => Controls_Manager::SELECT,
			  'label' => esc_html__('Category', 'archway'),
			  'label_block' => true,
			  'options' => get_project_categories()
			]
		);
		$this->end_controls_section();
				
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{	
			/**Layout Control Style**/		
		$this->start_controls_section(
			'archway_layout_style',
			[
				'label' => esc_html__('Archway Layout Setting', 'archway'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
            'archway_layout_margin',
            [
                'label'              => __( 'Spacing', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-project-section' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_responsive_control(
            'archway_layout_padding',
            [
                'label'              => __( 'Gapping', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-project-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_control(
			'archway_layout_background',
			[
				'label'                 => __( 'Background', 'archway' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'archway_layout_bgtype',
				'label' => __( 'Button Background', 'archway' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .archway-project-section',				
			]
		);
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');		
		
    	$paged = archway_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-archway' );
		$args = array(
			'post_type'      => 'project',
			'posts_per_page' => archway_set( $settings, 'query_number' ),
			'orderby'        => archway_set( $settings, 'query_orderby' ),
			'order'          => archway_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if( archway_set( $settings, 'query_category' ) ) $args['project_cat'] = archway_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
	{ ?>
    
    <?php if($settings['layout_control'] == '2') :?>
   	
    <!--Services Section-->
    <section class="portfolio-one archway-project-section">
        <div class="auto-container">
            <div class="row clearfix">
                <?php
					global $post;
					while ( $query->have_posts() ) : $query->the_post();
					$post_thumbnail_id = get_post_thumbnail_id($post->ID);
					$post_thumbnail_url = wp_get_attachment_url( $post_thumbnail_id );
					$term_list = wp_get_post_terms(get_the_id(), 'project_cat', array("fields" => "names"));			
				?>
                <!--Block-->
                <div class="s-block col-xl-4 col-lg-4 col-md-6 col-sm-12">
                    <div class="inner-box">
                        <div class="image-box">
                            <div class="image"><a href="<?php echo esc_url($post_thumbnail_url); ?>" class="lightbox-image"><?php the_post_thumbnail('archway_467x548'); ?></a></div>
                            <div class="cat"><span><?php echo implode( ', ', (array)$term_list );?></span></div>
                            <div class="link"><a href="<?php echo esc_url($post_thumbnail_url); ?>" class="lightbox-image"><span class="icon far fa-plus"></span></a></div>
                        </div>
                        <div class="lower-box">
                            <h3><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?>
            </div>
        </div>
    </section>
    
    <?php else: ?>
    
    <!--Services Section-->
    <section class="services-section no-pad-top archway-project-section">
        <div class="auto-container">
            <?php if($settings['title'] || $settings['btn_title']){ ?>
            <div class="title-box clearfix">
                <?php if($settings['title']){ ?><h2><?php echo wp_kses($settings['title'], true);?></h2><?php } ?>
                <?php if($settings['btn_title']){ ?>
                <div class="link-box"><a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="theme-btn btn-style-one"><span class="btn-box"><span class="btn-txt"><?php echo wp_kses($settings['btn_title'], true);?></span><i class="btn-arrow fal fa-arrow-right"></i></span></a></div>
            	<?php } ?>
            </div>
            <?php } ?>
            <div class="row clearfix">
                <?php
					global $post;
					while ( $query->have_posts() ) : $query->the_post();
					$post_thumbnail_id = get_post_thumbnail_id($post->ID);
					$post_thumbnail_url = wp_get_attachment_url( $post_thumbnail_id );
					$term_list = wp_get_post_terms(get_the_id(), 'project_cat', array("fields" => "names"));			
				?>
                <!--Block-->
                <div class="s-block col-xl-4 col-lg-4 col-md-6 col-sm-12 wow fadeInUp" data-wow-duration="1500ms" data-wow-delay="600ms">
                    <div class="inner-box">
                        <div class="image-box">
                            <div class="image"><a href="<?php echo esc_url($post_thumbnail_url); ?>" class="lightbox-image"><?php the_post_thumbnail('archway_467x548'); ?></a></div>
                            <div class="cat"><span><?php echo implode( ', ', (array)$term_list );?></span></div>
                            <div class="link"><a href="<?php echo esc_url($post_thumbnail_url); ?>" class="lightbox-image"><span class="icon far fa-plus"></span></a></div>
                        </div>
                        <div class="lower-box">
                            <h3><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?>
            </div>
        </div>
    </section>
        
    <?php endif; }
		wp_reset_postdata();
	}

}