<?php namespace ARCHWAYPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Grid extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'archway_service_grid';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Archway Service Grid', 'archway' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-banner';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'archway' ];
    }	
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'service_grid',
            [
                'label' => esc_html__( 'Service Grid', 'archway' ),
            ]
        );
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'archway'),
					'2' => esc_html__( 'Style Two ', 'archway'),
				),
			]
		);
		
		$this->add_control(
			'shape_image',
			[
				'label' => __( 'Shape Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,				
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);		
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'archway' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter your title', 'archway' ),
			]
		);
		
		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'archway' ),
				'type'    => Controls_Manager::NUMBER,		
				'default' => 15,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'archway' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'archway' ),
					'title'      => esc_html__( 'Title', 'archway' ),
					'menu_order' => esc_html__( 'Menu Order', 'archway' ),
					'rand'       => esc_html__( 'Random', 'archway' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'archway' ),
					'ASC'  => esc_html__( 'ASC', 'archway' ),
				),
			]
		);
		$this->add_control(
            'query_category', 
			[
			  'type' => Controls_Manager::SELECT,
			  'label' => esc_html__('Category', 'archway'),
			  'label_block' => true,
			  'options' => get_service_categories()
			]
		);
		$this->end_controls_section();
		
		/**Grid Setting Start**/
		$this->start_controls_section(
			'grid',
			[
				'label' => esc_html__( 'Grid Setting', 'archway' ),
			]
		);
		$this->add_control(
			'col_grid',
			[
				'label'   => esc_html__( 'Choose Column', 'archway' ),
				'label_block' => true,				
				'type'    => Controls_Manager::SELECT,
				'default' => 'four',
				'options' => array(
					'one' => esc_html__( 'One Column Grid ', 'archway'),
					'two'  => esc_html__( 'Two Column Grid', 'archway' ),
					'three'  => esc_html__( 'Three Column Grid', 'archway' ),
					'four'  => esc_html__( 'Four Column Grid', 'archway' ),
					'five'  => esc_html__( 'Six Column Grid', 'archway' ),
				),
			]
		);
		$this->end_controls_section();
			
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{	
		/**Layout Control Style**/		
		$this->start_controls_section(
			'archway_layout_style',
			[
				'label' => esc_html__('Archway Layout Setting', 'archway'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
            'archway_layout_margin',
            [
                'label'              => __( 'Spacing', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-service-grid' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_responsive_control(
            'archway_layout_padding',
            [
                'label'              => __( 'Gapping', 'archway' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .archway-service-grid' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				'frontend_available' => true,
				
            ]
        );
		$this->add_control(
			'archway_layout_background',
			[
				'label'                 => __( 'Background', 'archway' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'archway_layout_bgtype',
				'label' => __( 'Button Background', 'archway' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .archway-service-grid',				
			]
		);
		$this->end_controls_section();			
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');	
		$grid_col = $settings['col_grid'];
		
		if( $grid_col == 'one' ){
			$classes = 'col-lg-12 col-md-12 col-sm-12';
		}elseif( $grid_col == 'two' ){
			$classes = 'col-lg-6 col-md-6 col-sm-12';
		}elseif( $grid_col == 'three' ){
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}elseif( $grid_col == 'four' ){
			$classes = 'col-lg-3 col-md-6 col-sm-12';
		}elseif( $grid_col == 'five' ){
			$classes = 'col-lg-2 col-md-6 col-sm-12';
		}else{
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}
		
    	$paged = archway_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-archway' );
		$args = array(
			'post_type'      => 'service',
			'posts_per_page' => archway_set( $settings, 'query_number' ),
			'orderby'        => archway_set( $settings, 'query_orderby' ),
			'order'          => archway_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if( archway_set( $settings, 'query_category' ) ) $args['service_cat'] = archway_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
	{ ?>
    
    <?php if($settings['layout_control'] == '2') :?>
   	    
    <!-- Services Two -->
    <section class="services-two archway-service-grid" <?php if($settings['shape_image']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($settings['shape_image']['id'])); ?>);"<?php } ?>>
        <div class="auto-container">
            <?php if($settings['title']) { ?>
            <div class="sec-title centered">
                <h2><?php echo wp_kses($settings['title'], true);?></h2>
            </div>
            <?php } ?>
            <div class="row clearfix">
				<?php while ( $query->have_posts() ) : $query->the_post(); ?>
                <!-- Service Block Two -->
                <div class="service-block-two <?php echo esc_attr( $classes );?>">
                    <div class="inner-box">
                        <div class="icon-box fal <?php echo wp_kses(str_replace( "icon ",  "", get_post_meta(get_the_id(), 'service_icon', true )), true); ?>"></div>
                        <div class="image">
                            <?php the_post_thumbnail('archway_200x200'); ?>
                        </div>
                        <div class="overlay-box">
                            <div class="text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                        </div>
                        <h3><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                    </div>
                </div>
				<?php endwhile; ?>
            </div>
        </div>
    </section>
    <!-- End Services Two -->
    
    <?php else: ?>
    
    <!-- Services One -->
    <section class="services-one archway-service-grid" <?php if($settings['shape_image']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($settings['shape_image']['id'])); ?>);"<?php } ?>>
        <div class="auto-container">
            <?php if($settings['title']) { ?>
            <div class="sec-title centered">
                <h2><?php echo wp_kses($settings['title'], true);?></h2>
            </div>
            <?php } ?>
            <div class="row clearfix">
				<?php while ( $query->have_posts() ) : $query->the_post(); ?>
                <!-- Service Block One -->
                <div class="service-block-one <?php echo esc_attr( $classes );?>">
                    <div class="inner-box">
                        <h3><a href="<?php echo esc_url( get_the_permalink( get_the_id() ) );?>"><?php the_title(); ?> <span><img src="<?php echo esc_url(get_template_directory_uri());?>/assets/images/icons/arrow-right-1.png" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>" /></span></a></h3>
                        <div class="content">
                            <div class="text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                            <div class="icon">
                                <?php $service_icon_image = get_post_meta( get_the_id(), 'service_icon_image', true ); ?>
                                <img src="<?php echo wp_get_attachment_url($service_icon_image['id']);?>" alt="<?php esc_attr_e('Awesome Image', 'archway'); ?>" />
                            </div>
                        </div>
                    </div>
                </div>
				<?php endwhile; ?>                
            </div>
        </div>
    </section>
    <!-- End Services One -->
    
   	<?php endif; ?>   
    <?php }
		wp_reset_postdata();
	}

}