<?php

namespace ARCHWAYPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Testimonial_Carousel extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'archway_testimonial_carousel';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Archway Testimonial Carousel', 'archway' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-testimonial';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'archway' ];
	}
		
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'testimonial_carousel',
			[
				'label' => esc_html__( 'Testimonial Carousel', 'archway' ),
			]
		);
		
		$this->add_control(
			'shape_image',
			[
				'label' => __( 'Shape Image', 'archway' ),
				'type' => Controls_Manager::MEDIA,				
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label'       => __( 'Sub Title', 'archway' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'archway' ),
			]
		);
		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'archway' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,				
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'archway' ),
			]
		);
		
		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'archway' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 20,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'archway' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'archway' ),
					'title'      => esc_html__( 'Title', 'archway' ),
					'menu_order' => esc_html__( 'Menu Order', 'archway' ),
					'rand'       => esc_html__( 'Random', 'archway' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'archway' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'archway' ),
					'ASC'  => esc_html__( 'ASC', 'archway' ),
				),
			]
		);
		$this->add_control(
            'query_category', 
			[
			  'type' => Controls_Manager::SELECT,
			  'label' => esc_html__('Category', 'archway'),
			  'label_block' => true,
			  'options' => get_testimonials_categories()
			]
		);
		$this->end_controls_section();
				
		//General Style
		$this->start_controls_section(
			'general_style',
			[
				'label' => esc_html__( 'General Setting', 'archway' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
            'general_margin',
            [
                'label'      => esc_html__( 'Margin', 'archway' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .archway-testimonial-section' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		$this->add_responsive_control(
            'general_padding',
            [
                'label'      => esc_html__( 'Padding', 'archway' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .archway-testimonial-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'general_bgtype',
				'label' => __( 'Background', 'archway' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .archway-testimonial-section',				
			]
		);
		$this->end_controls_section();			
    }	

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');	
				
        $paged = archway_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-archway' );
		$args = array(
			'post_type'      => 'testimonials',
			'posts_per_page' => archway_set( $settings, 'query_number' ),
			'orderby'        => archway_set( $settings, 'query_orderby' ),
			'order'          => archway_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if( archway_set( $settings, 'query_category' ) ) $args['testimonials_cat'] = archway_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{ ?>
        
        <!-- Testimonial One -->
        <section class="testimonial-one archway-testimonial-section" <?php if($settings['shape_image']['id']){ ?> style="background-image: url(<?php echo esc_url(wp_get_attachment_url($settings['shape_image']['id'])); ?>);"<?php } ?>>
            <div class="auto-container">
                <?php if($settings['sub_title'] || $settings['title']) { ?>
                <div class="sec-title light centered">
                    <?php if($settings['sub_title']) { ?><div class="subtitle"><?php echo wp_kses($settings['sub_title'], true);?></div><?php } ?>
                    <?php if($settings['title']) { ?><h2><?php echo wp_kses($settings['title'], true);?></h2><?php } ?>
                </div>
                <?php } ?>                
                <div class="testi-carousel-three owl-carousel owl-theme">
    				<?php while ( $query->have_posts() ) : $query->the_post(); ?>
                    <!-- Testimonial Block One -->
                    <div class="testimonial-block-one">
                        <div class="inner-box">
                            <div class="author-box">
                                <div class="author-image">
                                    <?php the_post_thumbnail('archway_80x80'); ?>
                                </div>
                                <strong><?php the_title(); ?></strong>
                                <div class="designation"><?php echo (get_post_meta( get_the_id(), 'author_designation', true ));?></div>
                            </div>
                            <div class="text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                        </div>
                    </div>
    				<?php endwhile; ?>
                </div>
            </div>
        </section>
        <!-- End Testimonial One -->
        
        <?php }
		wp_reset_postdata();
	}

}
